/* src/math1/lrllib/lreqa.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* ----------------------------------------------------------------------- */
/*     LREQA */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
logical lreqa_(real *x, real *y, real *epsl)
{
    /* System generated locals */
    real r__1;
    logical ret_val;

    ret_val = (r__1 = *x - *y, dabs(r__1)) <= *epsl;
    return ret_val;
} /* lreqa_ */

